@@ -9,8 +9,12 @@ class APIException(Exception):
     code = None
     detail = None
 
+    def __init__(self, *args, **kwargs):
+        self.detail = self.detail.format(*args, **kwargs)
+        super().__init__(self.detail)
+
 
 class PermissionDenied(APIException):
     status_code = 403
     code = 'permission_denied'
-    detail = 'permission denied'
+    detail = '{detail}'
